@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
 // RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -25,6 +25,7 @@
 #include "wintypes.h"
 #include "KnownFile.h"
 #include "types.h"
+#include "NewFunctions.h"
 #include "opcodes.h"
 #include "BarShader.h"
 #include "ED2KLink.h"
@@ -95,7 +96,7 @@ public:
 	bool	IsPureGap(uint32 start, uint32 end);
 	bool	IsCorruptedPart(uint16 partnumber);
 	void	UpdateCompletedInfos();
-
+        
 	bool	GetNextRequestedBlock(CUpDownClient* sender,Requested_Block_Struct** newblocks,uint16* count);
 	void	WritePartStatus(CMemFile* file);
 	void	AddSources(CMemFile* sources,uint32 serverip, uint16 serverport);
@@ -182,30 +183,34 @@ public:
 	void	SetAutoDownPriority(bool flag) { m_bAutoDownPriority = flag; }
 	void	UpdateAutoDownPriority();
 	uint8	GetDownPriority()	{ return m_iDownPriority; }
+        // Acess to Flag for SourceSharing
+        bool    GetDisableXS()          { return m_DisableXS; }
+        void    SetDisableXS(bool in)   { m_DisableXS = in; }
 protected:
 	bool	GetNextEmptyBlockInPart(uint16 partnumber,Requested_Block_Struct* result);
 	bool	IsAlreadyRequested(uint32 start, uint32 end);
 	void	CompleteFile(bool hashingdone);
 	void	CreatePartFile();
 	void	Init();
-	wxMutex 	m_FileCompleteMutex; // Lord KiRon - Mutex for file completion
+	wxMutex 	m_FileCompleteMutex;  // Lord KiRon - Mutex for file completion
 private:
 	uint16	count;
 	uint16	transferingsrc;
 	uint32  completedsize;
 	uint64	m_iLostDueToCorruption;
 	uint64	m_iGainDueToCompression;
-	uint32  m_iTotalPacketsSavedDueToICH; 
+	uint32  m_iTotalPacketsSavedDueToICH;
 	uint32	datarate;
 	char*	fullname;
 	char*	partmetfilename;
 	uint32	transfered;
 	bool	paused;
 	bool	stopped;
+        bool    m_DisableXS;                  // Flag for SourceSharing
 	uint8	m_iDownPriority;
 	bool	m_bAutoDownPriority;
 	uint8	status;
-	bool	newdate;	// indicates if there was a writeaccess to the .part file
+	bool	newdate;	             // indicates if there was a writeaccess to the .part file
 	uint32	lastsearchtime;
 	uint32	lastpurgetime;
 	uint32	m_LastNoNeededCheck;
@@ -247,7 +252,7 @@ public:
 	void	SetMaxSourcesPerFile(uint16 in) { m_MaxSourcesPerFile=in; }
 	uint32  GetCompletedSize()   {return completedsize;}
 	
-	/* Razor 1a - Modif by MikaelB */
+	   /* Razor 1a - Modif by MikaelB */
 
           /* RemoveNoNeededSources function */
           void	RemoveNoNeededSources();
@@ -283,9 +288,8 @@ public:
           }
 
       private:
+	  MAP * listof_downloadingSources;
 
-          /* downloading sources list */
-          CTypedPtrList<CPtrList, CUpDownClient*> m_downloadingSourcesList;
 
           /* A4AF Auto attribute */
           bool m_IsA4AFAuto;
