@@ -49,7 +49,7 @@ class CSearchDlg : public wxPanel {
     virtual ~CSearchDlg();
     bool CheckTabNameExists(wxString searchString);
     void CreateNewTab(wxString searchString,wxUint32 nSearchID);
-    void LocalSearchEnd(char *packet,wxUint32 packetsize,wxUint32 nServerIP,wxUint16 nServerPort);
+    void SearchEnd(char *packet,wxUint32 packetsize,wxUint32 nServerIP,wxUint16 nServerPort);
     void UpdateCatChoice();
     enum {
         IDD = IDD_SEARCH 
@@ -62,7 +62,8 @@ class CSearchDlg : public wxPanel {
     void ButtonCancel(wxCommandEvent& evt);
     void ButtonDownload(wxCommandEvent& evt);
     void SearchDialogOnMouse(wxMouseEvent& evt);
-    private:
+private:
+    void Init();
     // event handlers
     void ButtonStart(wxCommandEvent& evt);
     void ButtonMore(wxCommandEvent& evt);
@@ -98,13 +99,11 @@ class CSearchDlg : public wxPanel {
     void ShowSearchResults();
     wxString CreateWebQuery();
     // private member variables
-    int srtab_deep,srtab_lock;
+    int srtab_deep, srtab_lock, srtab_refresh;
     int smaskhighest,smaskcurrent;
     wxComboBox typebox;
     wxComboBox Stypebox;
     wxImageList *ImageList;
-    wxImageList m_ImageList;
-    wxImageList m_StateImageList;
     wxTimer m_timer;
     wxStaticBitmap m_ctrlSearchFrm;
     wxStaticBitmap m_ctrlWebSearchFrm;
