@@ -1,4 +1,8 @@
-//this file is part of xMule
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
 //Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
@@ -48,6 +52,8 @@ public:
 	CServer*	GetServerAt(uint32 pos)	{return list.GetAt(list.FindIndex(pos));}
 	uint32		GetServerCount()	{return list.GetCount();}
 	CServer*	GetNextServer(CServer* lastserver); // slow
+	CServer*	GetServerByIP(wxUint32 nIP);
+	CServer*	GetServerByIP(wxUint32 nIP,wxUint16 nPort);
 	CServer*	GetServerByAddress(char* address, uint16 port);
 	bool		IsGoodServerIP( CServer* in_server ); //<<--
 	void		GetStatus( uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ);
