@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -20,6 +24,7 @@
 
 #include "types.h"
 #include "opcodes.h"
+#include "NewFunctions.h"                   // Needed for MAP-lists/tables
 #include "updownclient.h"
 #include "Preferences.h"
 
@@ -79,16 +84,17 @@ waitinglist.GetHeadPosition();}
 	uint32	GetSuccessfullUpCount()					{return successfullupcount;}
 	uint32	GetFailedUpCount()						{return failedupcount;}
 	uint32	GetAverageUpTime();
-	void	FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient*>* srclist, uchar* filehash);
+	void	FindSourcesForFileById(MAP* &listof_sources, unsigned char* filehash);
 	void	AddUpDataOverheadSourceExchange(uint32 data)	{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadSourceExchange += data;
 															  m_nUpDataOverheadSourceExchangePackets++;}
 	void	AddUpDataOverheadFileRequest(uint32 data)		{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadFileRequest += data;
 															  m_nUpDataOverheadFileRequestPackets++;}
-	void	AddUpDataOverheadServer(uint32 data)			{ m_nUpDataRateMSOverhead += data;
+	void	AddUpDataOverheadServer(uint32 data)	{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadServer += data;
 															  m_nUpDataOverheadServerPackets++;}
+
 	void	AddUpDataOverheadOther(uint32 data)				{ m_nUpDataRateMSOverhead += data;
 															  m_nUpDataOverheadOther += data;
 															  m_nUpDataOverheadOtherPackets++;}
