@@ -1,39 +1,47 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xmule project.
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This file was a part of eMule
+// Copyright (c) 2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+//
 #ifndef _OPCODES_H
 #ifndef _DUMP
-	#define CURRENT_VERSION_LONG	"0.34"
+	#define CURRENT_VERSION_LONG	"0.30"
 #else
-	#define CURRENT_VERSION_LONG	"0.34 DEBUG"
+	#define CURRENT_VERSION_LONG	"0.30 DEBUG"
 #endif
 #define WM_APP 5500
 
-#define MOD_VERSION             "xMule"
+//release:#define MOD_VERSION             "xMule"
+#define MOD_VERSION             "1.8.4"
 #define ET_MOD_VERSION 			0x55
 // MOD Note: Do not change this part - Merkur
-#define CURRENT_VERSION_SHORT	0x34
-#define CURRENT_VERSION_CHECK	0x34
+#define CURRENT_VERSION_SHORT	0x30
+#define CURRENT_VERSION_CHECK	0x30
 #define	EMULE_PROTOCOL			0x01
 // MOD Note: end
 #define	EDONKEYVERSION			0x3c
 #define PREFFILE_VERSION		0x14	//<<-- last change: reduced .dat, by using .ini
 #define PARTFILE_VERSION		0xe0
-#define CREDITFILE_VERSION		0x11
+#define CREDITFILE_VERSION		0x12
+#define CREDITFILE_VERSION_29		0x11
 #define COMPILE_DATE			__DATE__
 #define COMPILE_TIME			__TIME__
 #ifdef _DEBUG
@@ -42,10 +50,13 @@
 #define EMULE_GUID				"EMULE-{4EADC6FC-516F-4b7c-9066-97D893649569}"
 #endif
 
+#define SEC2MS(sec)		((sec)*1000)
+#define MIN2MS(min)		SEC2MS((min)*60)
+
 // MOD Note: Do not change this part - Merkur
-#define UDPSEARCHSPEED			1500	// if this value is too low you will miss sources
-#define MAX_RESULTS				200		// max global search results
-#define MAX_CLIENTCONNECTIONTRY	3
+#define UDPSEARCHSPEED			1000	// if this value is too low you will miss sources
+#define MAX_RESULTS				100		// max global search results
+#define MAX_CLIENTCONNECTIONTRY	2
 #define CONNECTION_TIMEOUT		40000	// set his lower if you want less connections at once, set it higher if you have enough sockets (edonkey has its own timout too, so a very high value won't effect this)
 #define	FILEREASKTIME			1300000	// **
 #define SERVERREASKTIME			800000  // don't set this too low, it wont speed up anything, but it could kill xmule or your internetconnection
@@ -73,11 +84,12 @@
 #define CONNECTION_LATENCY		22050	// latency for responces
 #define	SOURCESSLOTS			100
 #define MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE   1000
+#define MAXAVERAGETIME			40000 //milliseconds
 
 // you shouldn't change anything here if you are not really sure, or xmule will probaly not work
 #define	MAXFRAGSIZE				1300
 #define	PARTSIZE				9728000
-#define BLOCKSIZE				184320
+#define GAPBLOCKSIZE				184320
 #define OP_EDONKEYHEADER		0xE3
 #define OP_EDONKEYPROT			OP_EDONKEYHEADER
 #define OP_PACKEDPROT			0xD4
@@ -125,12 +137,13 @@
 #define OP_USERS_LIST           0x43    // <count 4>(<HASH 16><ID 4><PORT 2><1 Tag_set>)[count]
 
 //client <-> UDP server
+#define OP_GLOBSEARCHREQ2               0x92    // <search_tree_extended>
 #define OP_GLOBSERVSTATREQ		0x96	// (null)
 #define	OP_GLOBSERVSTATRES		0x97	// <USER 4><FILES 4>
 #define OP_GLOBSEARCHREQ		0x98	// <search_tree>
 #define OP_GLOBSEARCHRES		0x99	// 
 #define OP_GLOBGETSOURCES		0x9A	// <HASH 16>
-#define OP_GLOBFOUNDSORUCES		0x9B	//
+#define OP_GLOBFOUNDSOURCES		0x9B
 #define OP_GLOBCALLBACKREQ		0x9C	// <IP 4><PORT 2><client_ID 4>
 #define OP_INVALID_LOWID		0x9E	// <ID 4>
 #define	OP_SERVER_LIST_REQ		0xA0	// <IP 4><PORT 2>
@@ -171,9 +184,9 @@
 
 
 // extened prot client <-> extened prot client
-#define	OP_EMULEINFO			0x01	//
-#define	OP_EMULEINFOANSWER		0x02	//
-#define OP_COMPRESSEDPART		0x40	//
+#define	OP_EMULEINFO			0x01
+#define	OP_EMULEINFOANSWER		0x02
+#define OP_COMPRESSEDPART		0x40
 #define OP_QUEUERANKING			0x60	// <RANG 2>
 #define OP_FILEDESC				0x61	// <len 2><NAME len>
 #define OP_VERIFYUPSREQ			0x71	// (never used)
@@ -181,7 +194,12 @@
 #define OP_UDPVERIFYUPREQ		0x73	// (never used)
 #define OP_UDPVERIFYUPA			0x74	// (never used)
 #define OP_REQUESTSOURCES		0x81	// <HASH 16>
-#define OP_ANSWERSOURCES		0x82	//
+#define OP_ANSWERSOURCES		0x82	
+#define OP_PUBLICKEY			0x85	// <len 1><pubkey len>
+#define	OP_SIGNATURE			0x86	// v1: <len 1><signature len> v2:<len 1><signature len><sigIP used 1>
+#define OP_SECIDENTSTATE                0x87    // <state 1><rndchallenge 4>
+#define OP_REQUESTPREVIEW		0x90	// <HASH 16>
+#define OP_PREVIEWANSWER		0x91	// <HASH 16><frames 1>{ frames * <len 4><frame len>}
 
 // extened prot client <-> extened prot client UDP
 #define OP_REASKFILEPING		0x90	// <HASH 16>
@@ -195,9 +213,13 @@
 #define ST_PING					0x0C	// <int>
 #define ST_PREFERENCE			0x0E	// <int>
 #define ST_FAIL					0x0D	// <int>
-#define	ST_DYNIP				0x85
-#define ST_LASTPING				0x86	// <int>
+#define ST_DYNIP				0x85
 #define ST_MAXUSERS				0x87
+#define ST_SOFTFILES			0x88
+#define ST_HARDFILES			0x89
+#define ST_LASTPING				0x90	// <int>  New ID to trick xMule was 0x86
+#define ST_VERSION				0x91	// <string>
+#define	ST_UDPFLAGS				0x92	// <int>
 //file tags
 #define FT_FILENAME				0x01
 #define FT_FILESIZE				0x02	// <int>
@@ -227,9 +249,12 @@
 #define	FT_ATTRANSFEREDHI		0x54
 
 #define CT_NAME					0x01
-#define CT_VERSION				0x11
 #define	CT_PORT					0x0f
+#define CT_VERSION				0x11
 #define CT_FRIENDSHARING			0x66
+#define CT_EMULE_UDPPORTS			0xf9
+#define CT_EMULE_MISCOPTIONS1			0xfa
+#define CT_EMULE_VERSION			0xfb
 
 #define MP_MESSAGE				10102
 #define MP_DETAIL				10103
@@ -308,7 +333,7 @@
 #define ET_SOURCEEXCHANGE		0x23
 #define ET_COMMENTS				0x24
 #define ET_EXTENDEDREQUEST		0x25
-#define ET_COMPATABLECLIENT		0x30
+#define ET_COMPATIBLECLIENT		0x26
 #define ET_FEATURES			0x27	// bit 0: SecIdent v1
 						// bit 1: SecIdent v2
 
