@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
 // RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -41,6 +41,7 @@ public:
 	Packet(char* header); // only used for receiving packets
 	Packet(char* pPacketPart,uint32 nSize,bool bLast); // only used for splitted packets!
 	Packet(CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
+	//Packet(int8 in_opcode,CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
 	Packet(int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT);
 	Packet(int8 in_opcode,int32 in_size,uint8 protocol, unsigned char *buffer);
 	Packet(char* type,int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT,bool bFromPF = true);
@@ -75,7 +76,7 @@ struct Tag_Struct{
 	int8	type;
 	char*	tagname;
 	char*	stringvalue;
-	int32	intvalue;
+	uint32	intvalue;
 	int8	specialtag;
 	
 };
