@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
 // RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 // Author:      Julian Smart
 // Created:     01/02/97
 // Modified:
-// Id:          $Id: treebasc.cpp,v 1.2.16.3 2004/04/03 23:12:38 fsch2010 Exp $
+// Id:          $Id: treebasc.cpp,v 1.2.16.5 2004/04/30 21:13:21 fsch2010 Exp $
 // Copyright:   (c) 1998 Robert Roebling, Julian Smart et al
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -58,7 +58,6 @@
 #include "wx/dcclient.h"
 #include "wx/msgdlg.h"
 
-
 // ----------------------------------------------------------------------------
 // events
 // ----------------------------------------------------------------------------
@@ -89,14 +88,12 @@ DEFINE_EVENT_TYPE(wxEVT_COMMAND_CTREE_ITEM_LEFT_CLICK)
 
 IMPLEMENT_DYNAMIC_CLASS(wxCTreeEvent, wxNotifyEvent)
 
-
-wxCTreeEvent::wxCTreeEvent(wxEventType commandType, int id)
-: wxNotifyEvent(commandType, id) {
-	m_itemOld = 0l;
-	m_editCancelled = FALSE;
+wxCTreeEvent:: wxCTreeEvent(wxEventType commandType, int id)
+: wxNotifyEvent(commandType, id)
+{
+    m_itemOld = 0l;
+    m_editCancelled = FALSE;
 }
 
 #endif // wxUSE_CTRE_CTRL
 
-
-
