@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
 // RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -72,15 +72,16 @@ enum EClientSoftware {
 	SO_EMULE			= 0,
 	SO_CDONKEY			= 1,
 	SO_XMULE			= 2,
+	SO_AMULE			= 3,
 	SO_SHAREAZA			= 4,
-	SO_EDONKEYHYBRID	= 50,
+	SO_EDONKEYHYBRID		= 50,
 	SO_EDONKEY			= 51,
 	SO_MLDONKEY			= 52,
 	SO_OLDEMULE			= 53,
 	SO_UNKNOWN			= 54,
-	SO_NEW_MLDONKEY			= 153,
+	SO_NEW_MLDONKEY			= 152,
 };
-
+#define L 3
 enum ESecureIdentState {
 	IS_UNAVAILABLE = 0,
 	IS_ALLREQUESTSSEND = 0,
@@ -129,10 +130,10 @@ public:
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
 	int			GetHashType();
 	uint32			GetVersion()				{return m_nClientVersion;}
-	uint8			GetMuleVersion()			{return m_byEmuleVersion;}
+	uint8			GetMuleVersion()			{if(m_byEmuleVersion==0x99) return 0x42; else return m_byEmuleVersion;}
 	bool			ExtProtocolAvailable()		{return m_bEmuleProtocol;}
 	bool			IsEmuleClient()				{return m_byEmuleVersion;}
-	CClientCredits* Credits()					{return credits;}
+	CClientCredits* 	Credits()					{return credits;}
 	bool			IsBanned()	{return (m_bBanned && m_nDownloadState != DS_DOWNLOADING);}
 	char*			GetClientFilename()			{return m_pszClientFilename;}
 	wxString		GetClientFilename_NEW() const		{return m_strClientFilename;}
@@ -153,17 +154,19 @@ public:
 	void			SetUserName(char* pszNewName);
 	EClientSoftware		GetClientSoft()				{return m_clientSoft;}
 	void			ReGetClientSoft();
-	void			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
-	void			ProcessHelloPacket(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloPacket(char* pachPacket, uint32 nSize);
 	void			SendHelloAnswer();
 	void			SendHelloPacket();
 	void			SendMuleInfoPacket(bool bAnswer);
 	void			ProcessMuleInfoPacket(char* pachPacket, uint32 nSize);
 	void			ProcessMuleCommentPacket(char* pachPacket, uint32 nSize);
 	bool			Compare(CUpDownClient* tocomp);
-	void			SetLastSrcReqTime()			{m_dwLastSourceRequest = ::GetTickCount();}
+	void			SetLastStateChange()	{m_dwLastStateChange = ::GetTickCount();}
+	void			SetLastSrcReqTime()		{m_dwLastSourceRequest = ::GetTickCount();}
 	void			SetLastSrcAnswerTime()		{m_dwLastSourceAnswer = ::GetTickCount();}
 	void			SetLastAskedForSources()	{m_dwLastAskedForSources = ::GetTickCount();}
+	uint32			GetLastStateChange()	{return m_dwLastStateChange;}
 	uint32			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
 	uint32			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
 	uint32			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
@@ -171,9 +174,17 @@ public:
 	void			SetFriendSlot(bool bNV)		{m_bFriendSlot = bNV;}
 	void			SetCommentDirty(bool bDirty = true) {m_bCommentDirty = bDirty;}
 	uint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
+
+	void			SendPublicKeyPacket();
+	void			SendSignaturePacket();
+	void			ProcessPublicKeyPacket(uchar* pachPacket, uint32 nSize);
+	void			ProcessSignaturePacket(uchar* pachPacket, uint32 nSize);
 	uint8			GetSecureIdentState()		{return m_SecureIdentState;}
 	void			SendSecIdentStatePacket();
+	void			ProcessSecIdentStatePacket(unsigned char* pachPacket,wxUint32 nSize);
+	uint8			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
 	void			InfoPacketsReceived();
+	void			ResetFileStatusInfo();
 
 	bool			SupportsPreview()		{return m_bSupportsPreview;}
 	bool			SafeSendPacket(Packet* packet);
@@ -254,6 +265,7 @@ public:
 	uint32			CalculateDownloadRate();
 	uint16			GetAvailablePartCount();
 	//			SwapToAnotherFile(bool bIgnoreNoNeeded = false);   Razor 1a - Modif by MikaelB 
+
 	void			UDPReaskACK(uint16 nNewQR);
 	void			UDPReaskFNF();
 	void			UDPReaskForDownload();
@@ -267,6 +279,9 @@ public:
 	//chat
 	uint8			GetChatState()				{return m_byChatstate;}
 	void			SetChatState(uint8 nNewS)	{m_byChatstate = nNewS;}
+	bool			m_bIsSpammer;
+	uint8			m_cMessagesReceived; //Count of chatmessages he sent to me
+	uint8			m_cMessagesSend; //Count of chatmessages i sent to him
 
 	//File Comment 
     CString			GetFileComment()			{return m_strComment;} 
@@ -281,13 +296,15 @@ public:
 	void UpdateDisplayedInfo(bool force=false);
 	int  GetFileListRequested() { return m_iFileListRequested; }
 	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
+	uint8	m_cFailed;
+    bool deletethis;
 
 private:
 	CPartFile*		reqfile;
 
 	// base
 	void	Init();
-	void	ProcessHelloTypePacket(CSafeMemFile* data);
+	bool	ProcessHelloTypePacket(CSafeMemFile* data);
 	void	SendHelloTypePacket(CMemFile* data);
 	bool	m_bIsBotuser;
 //	bool	isfriend;
@@ -311,25 +328,31 @@ private:
 	uint8	m_bySourceExchangeVer;
 	uint8	m_byAcceptCommentVer;
 	uint8	m_byExtendedRequestsVer;
-	uint8	m_cFailed;
 	EClientSoftware	m_clientSoft;
 	uint32	m_dwLastSourceRequest;
 	uint32	m_dwLastSourceAnswer;
 	uint32  m_dwLastAskedForSources;
+	uint32  m_dwLastStateChange;
 	int	m_iFileListRequested;
 	bool	m_bFriendSlot;
 	bool	m_bCommentDirty;
 	bool	m_bIsHybrid;
 	bool	m_bIsML;
-	uint32	m_byCompatibleClient;
-	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
-	DWORD	m_lastRefreshedDLDisplay;
+	bool	m_bGPLEvildoer;
+	bool	m_bPreviewReqPending;
+	bool	m_bPreviewAnsPending;
+	uint16	m_nKadPort;
+	bool	m_bMultiPacket;
+
 	ESecureIdentState	m_SecureIdentState;
 	uint8	m_byInfopacketsReceived;
 	uint32	m_dwLastSignatureIP;
 	uint8	m_bySupportSecIdent;
-	bool	m_bSupportsPreview;
+	bool	m_bySupportsPreview;
 	
+	uint32	m_byCompatibleClient;
+	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
+	DWORD	m_lastRefreshedDLDisplay;
 
 	//upload
 	void CreateStandartPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
@@ -352,12 +375,15 @@ private:
 	uint16 m_nUpCompleteSourcesCount;
 	public:
 	uint8*		m_abyUpPartStatus;
+	uint16		m_lastPartAsked;
+	DWORD		m_dwEnteredConnectedState;
+	CString		m_strModVersion;
 	uint32		m_nSumForAvgUpDataRate;
 
 	private:
 	CList<int,int>	 m_AvarageUDR_list;
 	
-	CTypedPtrList<CPtrList, Packet*>				 m_BlockSend_queue;
+	CTypedPtrList<CPtrList, Packet*>	 m_BlockSend_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_BlockRequests_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DoneBlocks_list;
 	CTypedPtrList<CPtrList, Requested_File_Struct*>	 m_RequestedFiles_list;
@@ -384,7 +410,9 @@ private:
 	bool		m_bUDPPending;
 	uint32		m_nSumForAvgDownDataRate;
 	bool		m_bHashsetRequested;
-	bool		m_fSharedDirectories;
+	bool		m_bSharedDirectories;
+ 	bool		m_bNoViewSharedFiles;
+	bool		m_bSupportsPreview;
 
 	CList<int,int>	 m_AvarageDDR_list;
 	sint32		sumavgDDR;
